@@ -2,7 +2,7 @@
 automua™ is a trademark of "Gaspard d'Hautefeuille" and may not be used 
 by third parties without the prior written permission of the author.
 
-Copyright © 2022 Gaspard d'Hautefeuille: set default socket_type to TLS
+Copyright © 2022 Gaspard d'Hautefeuille: set default socket_type to TLS, replace legacy backref by back_populates
 Copyright © 2019-2022 Ralph Seichter
 
 This file is part of automua.
@@ -43,7 +43,7 @@ class Provider(db.Model):
     id = db.Column(db.Integer, nullable=False, primary_key=True, autoincrement=True)
     name = db.Column(db.String(128), nullable=False)
     short_name = db.Column(db.String(32), nullable=False)
-    domains = db.relationship('Domain', lazy='select', backref=db.backref('provider', lazy='joined'))
+    domains = db.relationship('Domain', lazy='select', back_populates='provider')
 
     def __repr__(self) -> str:
         return f'<Provider id={self.id} name={self.short_name}>'
@@ -58,8 +58,7 @@ class Server(db.Model):
     socket_type = db.Column(db.String(32), nullable=False, default='TLS')
     user_name = db.Column(db.String(64), nullable=False, default=PLACEHOLDER_ADDRESS)
     authentication = db.Column(db.String(32), nullable=False, default='plain')
-    domains = db.relationship('Domain', secondary=server_domain_map, lazy='subquery',
-                              backref=db.backref('servers', lazy='select'))
+    domains = db.relationship('Domain', secondary=server_domain_map, lazy='subquery', back_populates='servers')
 
     def __repr__(self) -> str:
         return f'<Server id={self.id} prio={self.prio} type={self.type} name={self.name}>'
@@ -73,8 +72,7 @@ class Davserver(db.Model):
     use_ssl = db.Column(db.Boolean, nullable=False)
     domain_required = db.Column(db.Boolean, nullable=False)
     user_name = db.Column(db.String(64), nullable=True)
-    domains = db.relationship('Domain', secondary=davserver_domain_map, lazy='subquery',
-                              backref=db.backref('davservers', lazy='select'))
+    domains = db.relationship('Domain', secondary=davserver_domain_map, lazy='subquery', back_populates='davservers')
 
     def __repr__(self) -> str:
         return f'<Davserver id={self.id} type={self.type} url={self.url}>'
@@ -91,7 +89,7 @@ class Ldapserver(db.Model):
     attr_cn = db.Column(db.String(32), nullable=True)
     bind_password = db.Column(db.String(128), nullable=True)
     bind_user = db.Column(db.String(128), nullable=True)
-    domains = db.relationship('Domain', lazy='select', backref=db.backref('ldapserver', lazy='joined'))
+    domains = db.relationship('Domain', lazy='select', back_populates='ldapserver')
 
     def __repr__(self) -> str:
         return f'<Ldapserver id={self.id} name={self.name}>'
@@ -102,6 +100,12 @@ class Domain(db.Model):
     name = db.Column(db.String(128), nullable=False, unique=True)
     provider_id = db.Column(db.Integer, db.ForeignKey('provider.id'), nullable=False)
     ldapserver_id = db.Column(db.Integer, db.ForeignKey('ldapserver.id'), nullable=True)
+    provider = db.relationship('Provider', lazy='joined', back_populates='domains')
+    servers = db.relationship('Server', secondary=server_domain_map, lazy='select', back_populates='domains')
+    davservers = db.relationship('Davserver', secondary=davserver_domain_map, lazy='select', back_populates='domains')
+    ldapserver = db.relationship('Ldapserver', lazy='joined', back_populates='domains')
+
+
 
     def __repr__(self) -> str:
         return f'<Domain id={self.id} name={self.name}>'
