@@ -15,4 +15,4 @@ python3 -m venv "${dir}"
 source "${dir}/bin/activate"
 
 set +e
-pip install -U pip hatch wheel || true
+pip install -U pip || true
